@@ -2,12 +2,12 @@ package Locale::TextDomain::OO::Lexicon::StoreJSON; ## no critic (TidyCode)
 
 use strict;
 use warnings;
-use JSON ();
+use JSON -support_by_pp, -no_export;
 use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.014';
+our $VERSION = '1.021';
 
 with qw(
     Locale::TextDomain::OO::Lexicon::Role::StoreFile
@@ -54,13 +54,13 @@ __END__
 
 Locale::TextDomain::OO::Lexicon::StoreJSON - Stores the lexicon for other programming languages
 
-$Id: StoreJSON.pm 604 2015-08-09 16:47:36Z steffenw $
+$Id: StoreJSON.pm 608 2015-08-10 06:16:36Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Lexicon/StoreJSON.pm $
 
 =head1 VERSION
 
-1.014
+1.021
 
 =head1 DESCRIPTION
 
